@@ -10,7 +10,7 @@ class KahootError(Exception):
 
 def authenticate(username, password):
     payload = {'username': username, 'password': password, 'grant_type': 'password'}
-    response = requests.post(f'{KAHOOT_URL}/authenticate', json=payload)
+    response = requests.post(KAHOOT_URL + '/authenticate', json=payload)
 
     if response.status_code != requests.codes.ok:
         raise KahootError('Authentication failed. Did you type your password correctly?') 
@@ -19,8 +19,8 @@ def authenticate(username, password):
 
 
 def create_quiz(quiz, access_token):
-    headers = {'Authorization': f'Bearer {access_token}'}
-    response = requests.post(f'{KAHOOT_URL}/kahoots', json=quiz, headers=headers)
+    headers = {'Authorization': 'Bearer ' + access_token}
+    response = requests.post(KAHOOT_URL + '/kahoots', json=quiz, headers=headers)
 
     if response.status_code != requests.codes.ok:
         raise KahootError('Failed to create quiz. The response was: ' + response.json()) 
